#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @section Options:
#' \itemize{
#'   \item \code{rlmstudio.quiet}: A logical value. If \code{TRUE}, suppresses informational console messages and progress bars across the package. Defaults to \code{FALSE}.
#' }
## usethis namespace: end
NULL
