% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unload.R
\name{lms_unload_all}
\alias{lms_unload_all}
\title{Unload all models from memory}
\usage{
lms_unload_all(host = "http://localhost:1234", ...)
}
\arguments{
\item{host}{Character. The host address of the local server. Defaults to
"http://localhost:1234".}

\item{...}{Additional arguments passed to the API request body for each
unload request.}
}
\value{
Invisibly returns a character vector of the \code{instance_id}s that
were successfully unloaded. If no models were currently loaded, it
invisibly returns \code{NULL}.
}
\description{
Retrieves a list of all currently loaded models and unloads them one by one.
}
\examples{
\dontrun{
lms_server_start()
lms_download("google/gemma-3-1b")
lms_load("google/gemma-3-1b")

# Unload all currently loaded models to clear VRAM
lms_unload_all()
}
}
\seealso{
\code{\link{lms_unload}}
}
