% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/setup.R
\name{has_lms}
\alias{has_lms}
\title{Check if LM Studio CLI is installed}
\usage{
has_lms()
}
\value{
A logical scalar: \code{TRUE} if the \code{lms} executable is found
on the system path, and \code{FALSE} otherwise.
}
\description{
Check if LM Studio CLI is installed
}
\examples{
\dontrun{
has_lms()
}
}
