% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/setup.R
\name{check_lms_version}
\alias{check_lms_version}
\title{Check if the installed LM Studio CLI meets the minimum requirement}
\usage{
check_lms_version(min_version = "0.4.0")
}
\arguments{
\item{min_version}{Character string of the required version. Default is
"0.4.0".}
}
\value{
A logical scalar: \code{TRUE} if the LM Studio CLI version meets or
exceeds the specified \code{min_version}, and \code{FALSE} otherwise.
}
\description{
Check if the installed LM Studio CLI meets the minimum requirement
}
\examples{
\dontrun{
check_lms_version("0.4.0")
}
}
