% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/serve.R
\name{lms_server_start}
\alias{lms_server_start}
\title{Start the LM Studio local server}
\usage{
lms_server_start(port = NULL, cors = FALSE)
}
\arguments{
\item{port}{Integer. Port to run the server on. If not provided, LM Studio
uses the last used port.}

\item{cors}{Logical. Enable CORS support for web application development.
Defaults to FALSE.}
}
\value{
Invisibly returns an integer representing the system exit code
(\code{0} for success).
}
\description{
Launches the LM Studio local server via the CLI, allowing you to interact
with loaded models via HTTP API calls.
}
\examples{
\dontrun{
# Start server on the default port
lms_server_start()

# Start server on a custom port with CORS enabled
lms_server_start(port = 8080, cors = TRUE)
}
}
\seealso{
\href{https://lmstudio.ai/docs/cli/serve/server-start}{LM Studio CLI Server Start Documentation}
}
