% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/daemon.R
\name{lms_daemon_start}
\alias{lms_daemon_start}
\title{Start the LM Studio headless daemon}
\usage{
lms_daemon_start()
}
\value{
Invisibly returns the process object (or 0 if already running).
}
\description{
Launches the \code{llmster} daemon in the background via the CLI. This is required
in headless environments (such as Linux servers) before loading models or
starting the local server.
}
\section{Desktop Users}{
 On desktop operating systems (macOS and Windows),
running this command may actually launch the LM Studio desktop application
to act as the backend engine. If the GUI is already open, this function
will simply detect the active instance and return successfully. While safe
to use, desktop users generally do not need to call this function and can
just open the application manually.
}

\examples{
\dontrun{
lms_daemon_start()
}
}
\seealso{
\href{https://lmstudio.ai/docs/developer/core/headless_llmster}{LM Studio Headless Daemon (llmster)}
}
