% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/chat_oop.R
\name{print.lms_chat_result}
\alias{print.lms_chat_result}
\title{Print an LM Studio chat result}
\usage{
\method{print}{lms_chat_result}(x, ...)
}
\arguments{
\item{x}{An object of class \code{lms_chat_result}.}

\item{...}{Additional arguments passed to print.}
}
\value{
Invisibly returns the input object \code{x}.
}
\description{
Custom print method for responses that include log probabilities. Displays
the text clearly and provides a summary of the metadata.
}
\keyword{internal}
