% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/daemon.R
\name{lms_daemon_stop}
\alias{lms_daemon_stop}
\title{Stop the LM Studio headless daemon}
\usage{
lms_daemon_stop(force = FALSE)
}
\arguments{
\item{force}{Logical. If \code{TRUE}, attempts to stop the local server before
shutting down the daemon. The daemon cannot be stopped while the server
is actively running. Defaults to \code{FALSE}.}
}
\value{
Invisibly returns the system exit code (0 for success).
}
\description{
Stops the \code{llmster} daemon via the CLI. Use this to clean up system resources when
you are completely finished using LM Studio in headless mode.
}
\section{Desktop Users}{

If the daemon is currently being managed by the LM Studio desktop
application, this function will fail. The CLI intentionally prevents
programmatic shutdowns of the GUI to avoid disrupting visual sessions.
In this scenario, you must close the desktop application manually.
}

\examples{
\dontrun{
lms_daemon_stop(force = TRUE)
}
}
