% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/path.R
\name{lms_path}
\alias{lms_path}
\title{Get the absolute path to the LMS executable}
\usage{
lms_path()
}
\value{
A character string specifying the absolute file path to the LM Studio
executable (\code{lms}) on the user's system.
}
\description{
Locates the LM Studio CLI (\code{lms}) on your system. It checks the
\code{RLMSTUDIO_LMS_PATH} environment variable first, then the system \code{PATH}, and
finally common installation directories.
}
\examples{
\dontrun{
lms_path()
}
}
