% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/download.R
\name{print.lms_download_status}
\alias{print.lms_download_status}
\title{Print method for LM Studio download status}
\usage{
\method{print}{lms_download_status}(x, ...)
}
\arguments{
\item{x}{An object of class \code{lms_download_status}.}

\item{...}{Additional arguments passed to print.}
}
\value{
Invisibly returns the input object \code{x}.
}
\description{
Print method for LM Studio download status
}
\examples{
\dontrun{
lms_server_start()

job_id <- lms_download("google/gemma-3-1b")
status <- lms_download_status(job_id)
print(status)
}
}
\keyword{internal}
