% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/chat_oop.R
\name{new_lms_chat_result}
\alias{new_lms_chat_result}
\title{Create a new LM Studio chat result}
\usage{
new_lms_chat_result(text = character(), logprobs = data.frame())
}
\arguments{
\item{text}{Character. The generated text response.}

\item{logprobs}{Dataframe. The token-level probability data.}
}
\value{
An object of class \code{lms_chat_result}.
}
\description{
Internal constructor to create a structured object for responses containing
log probabilities.
}
\keyword{internal}
