% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/download.R
\name{lms_download_status}
\alias{lms_download_status}
\title{Get the status of a download job}
\usage{
lms_download_status(job_id, host = "http://localhost:1234")
}
\arguments{
\item{job_id}{Character. The unique identifier for the download job.}

\item{host}{Character. The host address of the local server. Defaults to
"http://localhost:1234".}
}
\value{
An object of class \code{lms_download_status} containing the download
status.
}
\description{
Get the status of a download job
}
\examples{
\dontrun{
lms_server_start()

job_id <- lms_download("google/gemma-3-1b")
status <- lms_download_status(job_id)
print(status)
}
}
\seealso{
\href{https://lmstudio.ai/docs/developer/rest/download-status}{LM Studio Download Status API}
}
