% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rlmstudio-package.R
\docType{package}
\name{rlmstudio-package}
\alias{rlmstudio}
\alias{rlmstudio-package}
\title{rlmstudio: Access and Control LM Studio}
\description{
A community-maintained 'R' wrapper for the 'LM Studio' command line interface and API. Provides functions to manage the local daemon and server, download and load models, and interact with Large Language Models (LLMs).
}
\seealso{
Useful links:
\itemize{
  \item \url{https://jmgirard.github.io/rlmstudio/}
  \item \url{https://github.com/jmgirard/rlmstudio}
  \item Report bugs at \url{https://github.com/jmgirard/rlmstudio/issues}
}

}
\author{
\strong{Maintainer}: Jeffrey Girard \email{me@jmgirard.com} (\href{https://orcid.org/0000-0002-7359-3746}{ORCID}) [copyright holder]

Authors:
\itemize{
  \item Jeffrey Girard \email{me@jmgirard.com} (\href{https://orcid.org/0000-0002-7359-3746}{ORCID}) [copyright holder]
}

}
\keyword{internal}
