% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/chat_oop.R
\name{validate_lms_chat_result}
\alias{validate_lms_chat_result}
\title{Validate an LM Studio chat result}
\usage{
validate_lms_chat_result(x)
}
\arguments{
\item{x}{An object to validate.}
}
\value{
The validated object.
}
\description{
Internal validator to ensure the integrity of \code{lms_chat_result} objects.
}
\keyword{internal}
