% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/serve.R
\name{lms_server_stop}
\alias{lms_server_stop}
\title{Stop the LM Studio local server}
\usage{
lms_server_stop()
}
\value{
Invisibly returns an integer representing the system exit code
(\code{0} for success).
}
\description{
Stops the currently running LM Studio local server via the CLI.
}
\examples{
\dontrun{
lms_server_start()
lms_server_stop()
}
}
\seealso{
\href{https://lmstudio.ai/docs/cli/serve/server-stop}{LM Studio CLI Server Stop Documentation}
}
